@@ -187,16 +187,20 @@ def index():
     dbs = [{
         "name": key,
         "number": value["number"],
-        "version": value["version"]
+        "version": value["version"],
+        "url": url_for('database_explorer', name=key)
         } for key, value in databases.iteritems()]
+    dbs.sort(key=lambda x: x['name'])
     ms = [{
         "name": " - ".join(key),
         "unit": value["unit"],
-        "num_cfs": value["num_cfs"]
+        "num_cfs": value["num_cfs"],
+        "url": url_for("method_explorer", abbreviation=value['abbreviation'])
     } for key, value in methods.iteritems()]
+    ms.sort(key = lambda x: x['name'])
     context = {
-        'databases': dbs,
-        'methods': ms,
+        'databases': json.dumps(dbs),
+        'methods': json.dumps(ms),
         'config': config
         }
     return render_template("index.html", **context)
@@ -359,18 +363,33 @@ def filter_sort_process_database(data, filter=None, order=None):
 
 @app.route("/database/<name>")
 def database_explorer(name):
-    if name not in databases:
+    try:
+        meta = databases[name]
+    except KeyError:
         return abort(404)
-    db = Database(name)
-    data = db.load()
-    if request.args.get("q", None):
-        names = [x["name"] for x in data.values()]
-        names = process.extract(request.args.get("q"), names, limit=20)
-        data = filter_sort_process_database(data, filter=names, order=names)
-    else:
-        data = filter_sort_process_database(data)
-    return render_template("database.html",
-        name=name, data=JsonWrapper.dumps(data))
+    data = Database(name).load()
+    depends = [{
+        'name': obj,
+        'url': url_for('database_explorer', name=obj)
+    } for obj in sorted(meta['depends'])]
+    json_data = [{
+        'name': value['name'],
+        'categories': ",".join(value.get('categories', [])),
+        'location': value.get('location', ''),
+        'unit': value.get('unit', ''),
+        'url': url_for('json_editor', database=name, code=key[1]),
+        # 'url_raw': url_for('raw_edit', database=name, code=key),
+        'num_exchanges': len(value.get('exchanges', [])),
+        'key': key
+        } for key, value in data.iteritems()]
+    json_data.sort(key = lambda x: x['name'])
+    return render_template(
+        "database.html",
+        meta=meta,
+        name=name,
+        depends=depends,
+        data=JsonWrapper.dumps(json_data)
+    )
 
 
 def short_name(name):
@@ -418,27 +437,33 @@ def database_tree(name, code, direction="backwards"):
 #######################
 
 
-@app.route("/method-json/<name1>/<name2>/<name3>")
-def method_json(name1, name2, name3):
-    name = (name1, name2, name3)
-    print name, name in methods
-    if name not in methods:
+@app.route("/method/<abbreviation>")
+def method_explorer(abbreviation):
+    method = [key for key, value in methods.iteritems()
+        if value['abbreviation'] == abbreviation]
+    if not len(method) == 1:
         abort(404)
-    biosphere = Database("biosphere").load()
-    print "Biosphere loaded", len(biosphere)
-    cfs = [{"n": biosphere[x[0]]["name"],
-        "c": str(biosphere[x[0]]["categories"]),
-        "a": x[1]
-        } for x in Method(name).load().iteritems()]
-    cfs.sort()
-    return json_response(cfs)
-
-
-@app.route("/method/<name1>")
-@app.route("/method/<name1>/<name2>")
-@app.route("/method/<name1>/<name2>/<name3>")
-def method_explorer(name1, name2=None, name3=None):
-    return
+    method = method[0]
+    meta = methods[method]
+    json_data = []
+    for key, value, geo in Method(method).load():
+        flow = Database(key[0]).load()[key]
+        json_data.append({
+            'name': flow['name'],
+            'unit': flow.get('unit', ''),
+            'categories': ",".join(flow.get('categories', [])),
+            'cf': value['amount'] if isinstance(value, dict) else value,
+            'location': geo,
+            'url': url_for('json_editor', database=key[0], code=key[1])
+        })
+    json_data.sort(key=lambda x: x['name'])
+    return render_template(
+        "method.html",
+        name=method,
+        unit=meta['unit'],
+        description=meta['description'],
+        data=JsonWrapper.dumps(json_data)
+    )
 
 
 # use werkzeug.utils.secure_filename to check uploaded file names
